@@ -150,7 +150,7 @@ class InquiryInformationMixin(object):
                 return sync_wait(command.execute(asi))
             except AsiCheckConditionError, e:
                 (key, code) = (e.sense_obj.sense_key, e.sense_obj.additional_sense_code.code_name)
-                if (key, code) == ('NOT_READY', 'MEDIUM NOT PRESENT'):
+                if key == 'NOT_READY':
                     return False
                 if (key, code) == ('ILLEGAL_REQUEST', 'INVALID COMMAND OPERATION CODE'):
                     return False
