@@ -25,11 +25,18 @@ class MultipathFrameworkModel(object):
         """:returns: :class:`MultipathBlockDevice` object that matches the given path.
         :raises: KeyError if no such device is found"""
         from infi.storagemodel.linux.native_multipath import LinuxNativeMultipathBlockDevice
+        from infi.storagemodel.windows.native_multipath import WindowsNativeMultipathBlockDevice
         devices_dict = dict([(device.get_block_access_path(), device) for device in self.get_all_multipath_block_devices()])
         for value in devices_dict.values():
             if isinstance(value, LinuxNativeMultipathBlockDevice):
                 devices_dict[value.get_device_mapper_access_path()] = value
-        return devices_dict[path]
+            if isinstance(value, WindowsNativeMultipathBlockDevice):
+                devices_dict[r"\\.\{}".format(value.get_display_name())] = value
+        if path in devices_dict:
+            return devices_dict[path]
+        if path.upper() in devices_dict:
+            return devices_dict[path.upper()]
+        raise KeyError(path)
 
     #############################
     # Platform Specific Methods #
