@@ -1,5 +1,4 @@
 
-from infi.pyutils.lazy import cached_method, clear_cache
 from logging import getLogger
 from itertools import product
 
@@ -41,7 +40,7 @@ class DiskExists(object):
         devices = mp_devices + non_mp_devices
         for device in devices:
             device.get_scsi_test_unit_ready()
-        return any([device.get_scsi_serial_number() == self.scsi_serial_number \
+        return any([device.get_scsi_serial_number() == self.scsi_serial_number
                     for device in devices])
 
     def __repr__(self):
